+{
   entry => <<'ENTRY', # for DUCET v6.0.0
0629      ; [.1C54.0021.0002.0629] # ARABIC LETTER TEH MARBUTA
FE94      ; [.1C54.0021.0019.FE94] # ARABIC LETTER TEH MARBUTA FINAL FORM
FE93      ; [.1C54.0021.001A.FE93] # ARABIC LETTER TEH MARBUTA ISOLATED FORM
0649      ; [.1CE9.0021.0002.0649] # ARABIC LETTER ALEF MAKSURA
FBE8      ; [.1CE9.0021.0017.FBE8] # ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA INITIAL FORM
FBE9      ; [.1CE9.0021.0018.FBE9] # ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA MEDIAL FORM
FEF0      ; [.1CE9.0021.0019.FEF0] # ARABIC LETTER ALEF MAKSURA FINAL FORM
FEEF      ; [.1CE9.0021.001A.FEEF] # ARABIC LETTER ALEF MAKSURA ISOLATED FORM
FC90      ; [.1CE9.0021.001B.FC90] # ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF FINAL FORM
FC5D      ; [.1CE9.0021.001C.FC5D] # ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF ISOLATED FORM
ENTRY
};
