+{
   entry => <<'ENTRY', # for DUCET v6.0.0
010D      ; [.15D2.0020.0002.010D] # LATIN SMALL LETTER C WITH CARON
0063 030C ; [.15D2.0020.0002.010D] # LATIN SMALL LETTER C WITH CARON
010C      ; [.15D2.0020.0008.010C] # LATIN CAPITAL LETTER C WITH CARON
0043 030C ; [.15D2.0020.0008.010C] # LATIN CAPITAL LETTER C WITH CARON
0161      ; [.17A7.0020.0002.0161] # LATIN SMALL LETTER S WITH CARON
0073 030C ; [.17A7.0020.0002.0161] # LATIN SMALL LETTER S WITH CARON
0160      ; [.17A7.0020.0008.0160] # LATIN CAPITAL LETTER S WITH CARON
0053 030C ; [.17A7.0020.0008.0160] # LATIN CAPITAL LETTER S WITH CARON
017E      ; [.1845.0020.0002.017E] # LATIN SMALL LETTER Z WITH CARON
007A 030C ; [.1845.0020.0002.017E] # LATIN SMALL LETTER Z WITH CARON
017D      ; [.1845.0020.0008.017D] # LATIN CAPITAL LETTER Z WITH CARON
005A 030C ; [.1845.0020.0008.017D] # LATIN CAPITAL LETTER Z WITH CARON
ENTRY
};
