+{
   entry => <<'ENTRY', # for DUCET v6.0.0
0111      ; [.15E4.0021.0002.0111] # LATIN SMALL LETTER D WITH STROKE
0064 0335 ; [.15E4.0021.0002.0111] # LATIN SMALL LETTER D WITH STROKE
0110      ; [.15E4.0021.0008.0110] # LATIN CAPITAL LETTER D WITH STROKE
0044 0335 ; [.15E4.0021.0008.0110] # LATIN CAPITAL LETTER D WITH STROKE
00F0      ; [.15E4.0022.0002.00F0] # LATIN SMALL LETTER ETH
00D0      ; [.15E4.0022.0008.00D0] # LATIN CAPITAL LETTER ETH
00FE      ; [.17C9.0020.0003.00FE][.1667.0020.0003.00FE] # LATIN SMALL LETTER THORN
00DE      ; [.17C9.0020.0009.00DE][.1667.0020.0009.00DE] # LATIN CAPITAL LETTER THORN
0077      ; [.1812.0021.0002.0077] # LATIN SMALL LETTER W
0057      ; [.1812.0021.0008.0057] # LATIN CAPITAL LETTER W
00FC      ; [.1833.0021.0002.00FC] # LATIN SMALL LETTER U WITH DIAERESIS
0075 0308 ; [.1833.0021.0002.00FC] # LATIN SMALL LETTER U WITH DIAERESIS
00DC      ; [.1833.0021.0008.00DC] # LATIN CAPITAL LETTER U WITH DIAERESIS
0055 0308 ; [.1833.0021.0008.00DC] # LATIN CAPITAL LETTER U WITH DIAERESIS
01DC      ; [.1833.0021.0002.00FC][.0000.0035.0002.0300] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
01DB      ; [.1833.0021.0008.00DC][.0000.0035.0002.0300] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
01D8      ; [.1833.0021.0002.00FC][.0000.0032.0002.0301] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
01D7      ; [.1833.0021.0008.00DC][.0000.0032.0002.0301] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
01D6      ; [.1833.0021.0002.00FC][.0000.005B.0002.0304] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
01D5      ; [.1833.0021.0008.00DC][.0000.005B.0002.0304] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
01DA      ; [.1833.0021.0002.00FC][.0000.0041.0002.030C] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
01D9      ; [.1833.0021.0008.00DC][.0000.0041.0002.030C] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
0171      ; [.1833.0022.0002.0171] # LATIN SMALL LETTER U WITH DOUBLE ACUTE
0075 030B ; [.1833.0022.0002.0171] # LATIN SMALL LETTER U WITH DOUBLE ACUTE
0170      ; [.1833.0022.0008.0170] # LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
0055 030B ; [.1833.0022.0008.0170] # LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
00E5      ; [.18B9.0020.0002.00E5] # LATIN SMALL LETTER A WITH RING ABOVE
0061 030A ; [.18B9.0020.0002.00E5] # LATIN SMALL LETTER A WITH RING ABOVE
00C5      ; [.18B9.0020.0008.00C5] # LATIN CAPITAL LETTER A WITH RING ABOVE
0041 030A ; [.18B9.0020.0008.00C5] # LATIN CAPITAL LETTER A WITH RING ABOVE
212B      ; [.18B9.0020.0008.00C5] # ANGSTROM SIGN
01FB      ; [.18B9.0020.0002.00E5][.0000.0032.0002.0301] # LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE
01FA      ; [.18B9.0020.0008.00C5][.0000.0032.0002.0301] # LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE
00E4      ; [.18BA.0020.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
0061 0308 ; [.18BA.0020.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
00C4      ; [.18BA.0020.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
0041 0308 ; [.18BA.0020.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
01DF      ; [.18BA.0020.0002.00E4][.0000.005B.0002.0304] # LATIN SMALL LETTER A WITH DIAERESIS AND MACRON
01DE      ; [.18BA.0020.0008.00C4][.0000.005B.0002.0304] # LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON
00E6      ; [.18BA.0021.0002.00E6] # LATIN SMALL LETTER AE
00C6      ; [.18BA.0021.0008.00C6] # LATIN CAPITAL LETTER AE
1D2D      ; [.18BA.0021.0014.1D2D] # MODIFIER LETTER CAPITAL AE
01FD      ; [.18BA.0021.0002.00E6][.0000.0032.0002.0301] # LATIN SMALL LETTER AE WITH ACUTE
01FC      ; [.18BA.0021.0008.00C6][.0000.0032.0002.0301] # LATIN CAPITAL LETTER AE WITH ACUTE
01E3      ; [.18BA.0021.0002.00E6][.0000.005B.0002.0304] # LATIN SMALL LETTER AE WITH MACRON
01E2      ; [.18BA.0021.0008.00C6][.0000.005B.0002.0304] # LATIN CAPITAL LETTER AE WITH MACRON
0119      ; [.18BA.0022.0002.0119] # LATIN SMALL LETTER E WITH OGONEK
0065 0328 ; [.18BA.0022.0002.0119] # LATIN SMALL LETTER E WITH OGONEK
0118      ; [.18BA.0022.0008.0118] # LATIN CAPITAL LETTER E WITH OGONEK
0045 0328 ; [.18BA.0022.0008.0118] # LATIN CAPITAL LETTER E WITH OGONEK
00F6      ; [.18BB.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
006F 0308 ; [.18BB.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
00D6      ; [.18BB.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
004F 0308 ; [.18BB.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
022B      ; [.18BB.0020.0002.00F6][.0000.005B.0002.0304] # LATIN SMALL LETTER O WITH DIAERESIS AND MACRON
022A      ; [.18BB.0020.0008.00D6][.0000.005B.0002.0304] # LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON
00F8      ; [.18BB.0021.0002.00F8] # LATIN SMALL LETTER O WITH STROKE
006F 0338 ; [.18BB.0021.0002.00F8] # LATIN SMALL LETTER O WITH STROKE
00D8      ; [.18BB.0021.0008.00D8] # LATIN CAPITAL LETTER O WITH STROKE
004F 0338 ; [.18BB.0021.0008.00D8] # LATIN CAPITAL LETTER O WITH STROKE
01FF      ; [.18BB.0021.0002.00F8][.0000.0032.0002.0301] # LATIN SMALL LETTER O WITH STROKE AND ACUTE
01FE      ; [.18BB.0021.0008.00D8][.0000.0032.0002.0301] # LATIN CAPITAL LETTER O WITH STROKE AND ACUTE
0151      ; [.18BB.0022.0002.0151] # LATIN SMALL LETTER O WITH DOUBLE ACUTE
006F 030B ; [.18BB.0022.0002.0151] # LATIN SMALL LETTER O WITH DOUBLE ACUTE
0150      ; [.18BB.0022.0008.0150] # LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
004F 030B ; [.18BB.0022.0008.0150] # LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
0153      ; [.18BB.0023.0002.0153] # LATIN SMALL LIGATURE OE
0152      ; [.18BB.0023.0008.0152] # LATIN CAPITAL LIGATURE OE
00F4      ; [.18BB.0024.0002.00F4] # LATIN SMALL LETTER O WITH CIRCUMFLEX
006F 0302 ; [.18BB.0024.0002.00F4] # LATIN SMALL LETTER O WITH CIRCUMFLEX
00D4      ; [.18BB.0024.0008.00D4] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX
004F 0302 ; [.18BB.0024.0008.00D4] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX
1ED3      ; [.18BB.0024.0002.00F4][.0000.0035.0002.0300] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE
1ED2      ; [.18BB.0024.0008.00D4][.0000.0035.0002.0300] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE
1ED1      ; [.18BB.0024.0002.00F4][.0000.0032.0002.0301] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE
1ED0      ; [.18BB.0024.0008.00D4][.0000.0032.0002.0301] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE
1ED7      ; [.18BB.0024.0002.00F4][.0000.004E.0002.0303] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE
1ED6      ; [.18BB.0024.0008.00D4][.0000.004E.0002.0303] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE
1ED5      ; [.18BB.0024.0002.00F4][.0000.0064.0002.0309] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
1ED4      ; [.18BB.0024.0008.00D4][.0000.0064.0002.0309] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
1ED9      ; [.18BB.0024.0002.00F4][.0000.0070.0002.0323] # LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW
1ED8      ; [.18BB.0024.0008.00D4][.0000.0070.0002.0323] # LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW
ENTRY
};
