+{
   entry => <<'ENTRY', # for DUCET v6.0.0
0D82      ; [.21F7.0020.0002.0D82][.FFF1.0000.0000.0000] # SINHALA SIGN ANUSVARAYA
0D83      ; [.21F7.0020.0002.0D83][.FFF2.0000.0000.0000] # SINHALA SIGN VISARGAYA
0DA5      ; [.2202.0020.0002.0DA5] # SINHALA LETTER TAALUJA SANYOOGA NAAKSIKYAYA
0DA4      ; [.2203.0020.0002.0DA4] # SINHALA LETTER TAALUJA NAASIKYAYA
ENTRY
};
