+{
   entry => <<'ENTRY', # for DUCET v6.0.0
0109      ; [.15D2.0020.0002.0109] # LATIN SMALL LETTER C WITH CIRCUMFLEX
0063 0302 ; [.15D2.0020.0002.0109] # LATIN SMALL LETTER C WITH CIRCUMFLEX
0108      ; [.15D2.0020.0008.0108] # LATIN CAPITAL LETTER C WITH CIRCUMFLEX
0043 0302 ; [.15D2.0020.0008.0108] # LATIN CAPITAL LETTER C WITH CIRCUMFLEX
011D      ; [.1645.0020.0002.011D] # LATIN SMALL LETTER G WITH CIRCUMFLEX
0067 0302 ; [.1645.0020.0002.011D] # LATIN SMALL LETTER G WITH CIRCUMFLEX
011C      ; [.1645.0020.0008.011C] # LATIN CAPITAL LETTER G WITH CIRCUMFLEX
0047 0302 ; [.1645.0020.0008.011C] # LATIN CAPITAL LETTER G WITH CIRCUMFLEX
0125      ; [.1668.0020.0002.0125] # LATIN SMALL LETTER H WITH CIRCUMFLEX
0068 0302 ; [.1668.0020.0002.0125] # LATIN SMALL LETTER H WITH CIRCUMFLEX
0124      ; [.1668.0020.0008.0124] # LATIN CAPITAL LETTER H WITH CIRCUMFLEX
0048 0302 ; [.1668.0020.0008.0124] # LATIN CAPITAL LETTER H WITH CIRCUMFLEX
0135      ; [.169A.0020.0002.0135] # LATIN SMALL LETTER J WITH CIRCUMFLEX
006A 0302 ; [.169A.0020.0002.0135] # LATIN SMALL LETTER J WITH CIRCUMFLEX
0134      ; [.169A.0020.0008.0134] # LATIN CAPITAL LETTER J WITH CIRCUMFLEX
004A 0302 ; [.169A.0020.0008.0134] # LATIN CAPITAL LETTER J WITH CIRCUMFLEX
015D      ; [.17A7.0020.0002.015D] # LATIN SMALL LETTER S WITH CIRCUMFLEX
0073 0302 ; [.17A7.0020.0002.015D] # LATIN SMALL LETTER S WITH CIRCUMFLEX
015C      ; [.17A7.0020.0008.015C] # LATIN CAPITAL LETTER S WITH CIRCUMFLEX
0053 0302 ; [.17A7.0020.0008.015C] # LATIN CAPITAL LETTER S WITH CIRCUMFLEX
016D      ; [.17EA.0020.0002.016D] # LATIN SMALL LETTER U WITH BREVE
0075 0306 ; [.17EA.0020.0002.016D] # LATIN SMALL LETTER U WITH BREVE
016C      ; [.17EA.0020.0008.016C] # LATIN CAPITAL LETTER U WITH BREVE
0055 0306 ; [.17EA.0020.0008.016C] # LATIN CAPITAL LETTER U WITH BREVE
ENTRY
};
