+{
   entry => <<'ENTRY', # for DUCET v6.0.0
00F1      ; [.1703.0020.0002.00F1] # LATIN SMALL LETTER N WITH TILDE
006E 0303 ; [.1703.0020.0002.00F1] # LATIN SMALL LETTER N WITH TILDE
00D1      ; [.1703.0020.0008.00D1] # LATIN CAPITAL LETTER N WITH TILDE
004E 0303 ; [.1703.0020.0008.00D1] # LATIN CAPITAL LETTER N WITH TILDE
ENTRY
};
