+{
   entry => <<'ENTRY', # for DUCET v6.0.0
0161      ; [.17C6.0020.0002.0161] # LATIN SMALL LETTER S WITH CARON
0073 030C ; [.17C6.0020.0002.0161] # LATIN SMALL LETTER S WITH CARON
0160      ; [.17C6.0020.0008.0160] # LATIN CAPITAL LETTER S WITH CARON
0053 030C ; [.17C6.0020.0008.0160] # LATIN CAPITAL LETTER S WITH CARON
007A      ; [.17C7.0020.0002.007A] # LATIN SMALL LETTER Z
005A      ; [.17C7.0020.0008.005A] # LATIN CAPITAL LETTER Z
017E      ; [.17C8.0020.0002.017E] # LATIN SMALL LETTER Z WITH CARON
007A 030C ; [.17C8.0020.0002.017E] # LATIN SMALL LETTER Z WITH CARON
017D      ; [.17C8.0020.0008.017D] # LATIN CAPITAL LETTER Z WITH CARON
005A 030C ; [.17C8.0020.0008.017D] # LATIN CAPITAL LETTER Z WITH CARON
0077      ; [.1812.0021.0002.0077] # LATIN SMALL LETTER W
0057      ; [.1812.0021.0008.0057] # LATIN CAPITAL LETTER W
00F5      ; [.182A.0020.0002.00F5] # LATIN SMALL LETTER O WITH TILDE
006F 0303 ; [.182A.0020.0002.00F5] # LATIN SMALL LETTER O WITH TILDE
00D5      ; [.182A.0020.0008.00D5] # LATIN CAPITAL LETTER O WITH TILDE
004F 0303 ; [.182A.0020.0008.00D5] # LATIN CAPITAL LETTER O WITH TILDE
1E4D      ; [.182A.0020.0002.00F5][.0000.0032.0002.0301] # LATIN SMALL LETTER O WITH TILDE AND ACUTE
1E4C      ; [.182A.0020.0008.00D5][.0000.0032.0002.0301] # LATIN CAPITAL LETTER O WITH TILDE AND ACUTE
022D      ; [.182A.0020.0002.00F5][.0000.005B.0002.0304] # LATIN SMALL LETTER O WITH TILDE AND MACRON
022C      ; [.182A.0020.0008.00D5][.0000.005B.0002.0304] # LATIN CAPITAL LETTER O WITH TILDE AND MACRON
1E4F      ; [.182A.0020.0002.00F5][.0000.0047.0002.0308] # LATIN SMALL LETTER O WITH TILDE AND DIAERESIS
1E4E      ; [.182A.0020.0008.00D5][.0000.0047.0002.0308] # LATIN CAPITAL LETTER O WITH TILDE AND DIAERESIS
1EE1      ; [.182A.0020.0002.00F5][.0000.0068.0002.031B] # LATIN SMALL LETTER O WITH HORN AND TILDE
1EE0      ; [.182A.0020.0008.00D5][.0000.0068.0002.031B] # LATIN CAPITAL LETTER O WITH HORN AND TILDE
00E4      ; [.182B.0020.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
0061 0308 ; [.182B.0020.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
00C4      ; [.182B.0020.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
0041 0308 ; [.182B.0020.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
01DF      ; [.182B.0020.0002.00E4][.0000.005B.0002.0304] # LATIN SMALL LETTER A WITH DIAERESIS AND MACRON
01DE      ; [.182B.0020.0008.00C4][.0000.005B.0002.0304] # LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON
00F6      ; [.182C.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
006F 0308 ; [.182C.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
00D6      ; [.182C.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
004F 0308 ; [.182C.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
022B      ; [.182C.0020.0002.00F6][.0000.005B.0002.0304] # LATIN SMALL LETTER O WITH DIAERESIS AND MACRON
022A      ; [.182C.0020.0008.00D6][.0000.005B.0002.0304] # LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON
00FC      ; [.182D.0020.0002.00FC] # LATIN SMALL LETTER U WITH DIAERESIS
0075 0308 ; [.182D.0020.0002.00FC] # LATIN SMALL LETTER U WITH DIAERESIS
00DC      ; [.182D.0020.0008.00DC] # LATIN CAPITAL LETTER U WITH DIAERESIS
0055 0308 ; [.182D.0020.0008.00DC] # LATIN CAPITAL LETTER U WITH DIAERESIS
01DC      ; [.182D.0020.0002.00FC][.0000.0035.0002.0300] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
01DB      ; [.182D.0020.0008.00DC][.0000.0035.0002.0300] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
01D8      ; [.182D.0020.0002.00FC][.0000.0032.0002.0301] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
01D7      ; [.182D.0020.0008.00DC][.0000.0032.0002.0301] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
01D6      ; [.182D.0020.0002.00FC][.0000.005B.0002.0304] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
01D5      ; [.182D.0020.0008.00DC][.0000.005B.0002.0304] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
01DA      ; [.182D.0020.0002.00FC][.0000.0041.0002.030C] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
01D9      ; [.182D.0020.0008.00DC][.0000.0041.0002.030C] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
ENTRY
};
